@@ -1,10 +1,14 @@
 /// Currently there is only 1 error type which is not enough bytes provided to slice at field.
 /// (amount of bytes provided , amount of bytes required)
+#[cfg(feature = "std")] 
+use std::fmt;
+#[cfg(not(feature = "std"))] 
+use core::fmt;
 #[derive(Debug)]
 pub struct BitfieldSliceError(pub usize, pub usize);
 
-impl std::fmt::Display for BitfieldSliceError {
-    fn fmt(&self, fmt: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+impl fmt::Display for BitfieldSliceError {
+    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(
             fmt,
             "expected {} bytes, {} bytes were provided.",
@@ -12,13 +16,15 @@ impl std::fmt::Display for BitfieldSliceError {
         )
     }
 }
+
+#[cfg(feature = "std")]
 impl std::error::Error for BitfieldSliceError {}
 
 #[derive(Debug)]
 pub struct BitfieldHexError(pub char, pub usize);
 
-impl std::fmt::Display for BitfieldHexError {
-    fn fmt(&self, fmt: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+impl fmt::Display for BitfieldHexError {
+    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(
             fmt,
             "found Invalid character {} @ index {}.",
